==> apache-fineract-1.8.4-src.tar.gz: apache-fineract-src-1.8.4/fineract-provider/src/main/java/org/apache/fineract/infrastructure/survey/data/ClientScoresOverview.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.fineract.infrastructure.survey.data;

import java.time.LocalDate;

/**
 * Created by Cieyou on 3/18/14.
 */
public class ClientScoresOverview {

    @SuppressWarnings("unused")
    private final String surveyName;
    @SuppressWarnings("unused")
    private final long id;
    @SuppressWarnings("unused")
    private final String likelihoodCode;
    @SuppressWarnings("unused")
    private final String likelihoodName;
    @SuppressWarnings("unused")
    private final long score;
    @SuppressWarnings("unused")
    private final Double povertyLine;
    @SuppressWarnings("unused")
    private final LocalDate date;

    public ClientScoresOverview(final String likelihoodCode, final String likelihoodName, final long score, final Double povertyLine,
            final LocalDate date, final long resourceId, final String surveyName) {

        this.likelihoodCode = likelihoodCode;
        this.likelihoodName = likelihoodName;
        this.score = score;
        this.povertyLine = povertyLine;
        this.date = date;
        this.id = resourceId;
        this.surveyName = surveyName;

    }
}

==> apache-fineract-1.9.0-src.tar.gz: apache-fineract-src-1.9.0/fineract-provider/src/main/java/org/apache/fineract/infrastructure/survey/data/ClientScoresOverview.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.fineract.infrastructure.survey.data;

import java.time.LocalDate;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;

/**
 * Created by Cieyou on 3/18/14.
 */
@Data
@NoArgsConstructor
@Accessors(chain = true)
public class ClientScoresOverview {

    @SuppressWarnings("unused")
    private String surveyName;
    @SuppressWarnings("unused")
    private long id;
    @SuppressWarnings("unused")
    private String likelihoodCode;
    @SuppressWarnings("unused")
    private String likelihoodName;
    @SuppressWarnings("unused")
    private long score;
    @SuppressWarnings("unused")
    private Double povertyLine;
    @SuppressWarnings("unused")
    private LocalDate date;
}
